/**
  *  \file planetscentral/talk/cmdsyntax.cc
  *  \brief Talk: SYNTAX commands
  */

#include "planetscentral/talk/cmdsyntax.h"
#include "int/args.h"
#include "int/array.h"
#include "int/value.h"
#include "planetscentral/dbclient/connection.h"
#include "planetscentral/talk/syntaxdb.h"
#include "planetscentral/talk/syntaxnames.h"
#include "planetscentral/talk/talkconnection.h"

/* @q SYNTAXGET key:Str (Talk Command)
   Get syntax coloring key.
   This queries the syntax coloring database that is usually used for rendering code.

   Valid keys:
   - <tt>ini.SECTION.NAME.info</tt>: help text for %NAME in section %SECTION.
   - <tt>ini.SECTION.NAME.link</tt>: link URL for %NAME in section %SECTION.

   Permissions: none.

   @err 404 Not found (key not found)
   @retval Str result */
void
doSyntaxGet(TalkConnection& conn, IntArgBlock& args)
{
    args.checkArgumentCount(1);
    string_t key = toStringResult(args.getNext());
    if (syntax_db.has(key)) {
        IntStringValue sv(syntax_db.get(key));
        conn.sendObject(&sv);
    } else {
        conn.sendError("404 Not found");
    }
}

/* @q SYNTAXMGET key:Str... (Talk Command)
   Get syntax coloring keys.

   Permissions: none.

   @see SYNTAXGET
   @retval StrList results. If a key cannot be found, the result is reported as null; no error is generated. */
void
doSyntaxMGet(TalkConnection& conn, IntArgBlock& args)
{
    Ptr<IntArrayData> ad(new IntArrayData());
    while (args.getNumArgs() > 0) {
        string_t key = toStringResult(args.getNext());
        if (syntax_db.has(key)) {
            ad->content.pushNew(new IntStringValue(syntax_db.get(key)));
        } else {
            ad->content.pushNew(0);
        }
    }
    ad->addDimension(ad->content.size());
    IntArray av(ad);
    conn.sendObject(&av);
}
