/**
  *  \file planetscentral/talk/syntaxscript.h
  *  \brief Talk: Syntax Highlighter for CCScript
  */
#ifndef C2SERVER_PLANETSCENTRAL_TALK_SYNTAXSCRIPT_H
#define C2SERVER_PLANETSCENTRAL_TALK_SYNTAXSCRIPT_H

#include "planetscentral/talk/syntax.h"

class SyntaxDatabase;

/** Highlighter for CCScript (*.q files). */
class SyntaxScript : public SyntaxHighlighter {
 public:
    SyntaxScript(const SyntaxDatabase& db);
    ~SyntaxScript();
    void init(const string_t& str);
    bool scan(Segment& result);

 private:
    const SyntaxDatabase& db;
    string_t str;
    string_t::size_type pos;

    enum State {
        sDefaultBOL,            // standard highlighting, beginning of line (=detection of keywords)
        sDefault,               // standard highlighting, within statement
        sAfterSub,              // I have seen "Sub" or "Function"
        sAfterSubDef,           // I have seen a parameter name, and expect a comma for the next one
        sAfterDim,              // I have seen "Dim" or "Local"
        sAfterDimDef,           // I have seen "Dim" or "Local", and expect a comma for the next definition
        sAfterFor,              // I have seen "For", "To" now is a keyword
        sAfterLoop,             // I have seen "Do" or "Loop", "Until" now is a keyword
        sAfterIf,               // I have seen "If", "Then" now is a keyword
        sAfterCase,             // I have seen "Case", "Is" now is a keyword
        sAfterWith              // I have seen "With" or "On"
    };
    State state;
    int paren_level;

    void leaveDefault();
};

#endif
